﻿// O(M*N) lahendus, S=P^2+Q^2
using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;

namespace Tort
{
    static class Program
    {
        static void Main()
        {
            LahendaFail("tortsis.txt", "tortval.txt");
        }

        private static void LahendaFail(string input, string output)
        {
            StreamReader reader = new StreamReader(input);
            string line = reader.ReadLine();
            List<int> parts = line.Split().Select(Int32.Parse).ToList();
            int M = parts[0];
            int N = parts[1];
            int S = parts[2];
            int P = parts[3];
            int Q = parts[4];

            var kokku = new Lahendaja(M, N, S, P, Q).Lahenda();

            StreamWriter writer = new StreamWriter(output);
            writer.WriteLine(kokku);
            writer.Close();
        }

        private class Lahendaja
        {
            private int _m, _n, _s, _p, _q, _s2;
            private Rational _suheX, _suheY;
            private Rational _reduce;
            private Rational _perioodX;
            private Rational _perioodY;
            private Rational _rs2;
            public Lahendaja(int m, int n, int s, int p, int q)
            {
                _m = m;
                _n = n;
                _s = s;
                _p = p;
                _q = q;

                Rational suhe = new Rational(_p, _q);
                _p = suhe.Num;
                _q = suhe.Denom;

                _suheX = new Rational(_p, _q);
                _suheY = new Rational(_q, _p);

                _s2 = _p * _p + _q * _q; // "suure ruudu" pindala
                _rs2 = new Rational(_s2);
                _reduce = (new Rational(_s) / _rs2).ISqrt(); // Because of Quantum

                _perioodX = new Rational(_s2, _q) * _reduce;
                _perioodY = new Rational(_s2, _p) * _reduce;
            }

            public int Lahenda()
            {
                int kokku = _m * _n;
                Rational rm = new Rational(_m);
                kokku += LeiaRuudud(_n, _m, Rational.Zero, _perioodX, _suheX, _p);  // tousvad diagonaalid, alt küljest 
                kokku += LeiaRuudud(_m, _n, _perioodY, _perioodY, _suheY, _q);  // tousvad diagonaalid, vasakult küljest 

                Rational esimene = new Rational(_p) + new Rational(_q) / _suheX;
                Rational viimane = (rm - esimene) % _perioodY;
                kokku += LeiaRuudud(_n, _m, viimane, _perioodY, _suheY, _q, true);  // langevad diagonaalid, alt küljest 

                Rational yleyhe = rm - viimane + _perioodY;
                Rational kyljel = (yleyhe - rm) * _suheX;
                Rational nihe = Rational.Zero;
                Rational algpunkt = kyljel;
                while (!algpunkt.IsInt)
                {
                    algpunkt -= _perioodX;
                }
                kokku += LeiaRuudud(_m, _n, kyljel, _perioodX, _suheX, _p, false, -algpunkt);  // langevad diagonaalid, paremalt küljest 
                return kokku;
            }

            private int LeiaRuudud(int ridu, int veerge, Rational algus, Rational periood, Rational suhe, int solmevahe, bool tagant = false, Rational nihe = null)
            {
                Rational algpunkt = algus;

                int c = 0;
                Rational rv = new Rational(veerge);
                Rational rm = new Rational(solmevahe);
                for (; algus < veerge; algus += periood)
                {
                    Rational lopp;
                    // kas ulatub teise serva?
                    if ((rv - algus) / suhe >= ridu)
                    {
                        lopp = algus + ridu * suhe;
                    }
                    else
                    {
                        lopp = new Rational(veerge);
                    }

                    Rational pikkus = lopp - algus;
                    Rational korgus = pikkus / suhe;

                    c += korgus.Ceil() - 1;  // vert ruudud
                    c += lopp.Ceil() - algus.Floor(); // hor ruudud

                    Rational baas = tagant ? rv - algus : algus;
                    if (nihe != null)
                    {
                        baas += nihe;
                    }
                    Rational lisa = (_rs2 - baas) / _rs2 % new Rational(1);

                    Rational tsykleid = (lisa * rm + pikkus) / rm;
                    int solmi = tsykleid.Floor();
                    if (tsykleid.IsInt)  // viimast ei loe
                    {
                        solmi--;
                    }

                    c -= solmi;
                }

                return c;
            }
        }

        public class Rational
        {
            private int _numerator = 0;
            private int _denominator = 1;

            public Rational(int intvalue)
            {
                Set(intvalue, 1);
            }

            public Rational(int numerator, int denominator)
            {
                Set(numerator, denominator);
                Reduce();
            }

            public static Rational Zero => new Rational(0);

            public int Num => _numerator;
            public int Denom => _denominator;

            public bool IsInt => _denominator == 1;

            private void Set(int numerator, int denominator)
            {
                if (denominator == 0)
                {
                    throw new ArithmeticException("Denominator must not be 0");
                }

                _numerator = numerator;
                _denominator = denominator;
            }

            private static Tuple<int, int> CommonBase(Rational r1, Rational r2)
            {
                int lcm = Lcm(r1._denominator, r2._denominator);
                int num1 = lcm / r1._denominator * r1._numerator;
                int num2 = lcm / r2._denominator * r2._numerator;

                return new Tuple<int, int>(num1, num2);
            }

            private static int Lcm(int v1, int v2)
            {
                return v1 * v2 / Gcd(v1, v2);
            }

            private static int Gcd(int a, int b)
            {
                if (a == 0)
                    return b;
                return Gcd(b % a, a);
            }

            private void Reduce()
            {
                int divisor = Math.Sign(_denominator) * Gcd(Math.Abs(_numerator), Math.Abs(_denominator));
                if (divisor == 0)
                {
                    _numerator = 0;
                    _denominator = 1;
                }
                else
                {
                    _numerator /= divisor;
                    _denominator /= divisor;
                }
            }

            private static int ISqrt(int n)
            {
                int current = n;
                int next = 1;
                while (current != next)  // newtoni meetod
                {
                    current = next;
                    next = (current + n / current) / 2;
                }

                return current;
            }

            public Rational ISqrt()
            {
                return new Rational(ISqrt(Num), ISqrt(Denom));
            }

            public int Ceil()
            {
                return Num / Denom + Math.Sign(Num % Denom);
            }

            public int Floor()
            {
                return Num / Denom;
            }

            public static bool operator ==(Rational r1, Rational r2)
            {
                if (ReferenceEquals(r1, null) && ReferenceEquals(r2, null)) return true;
                if (ReferenceEquals(r1, null) || ReferenceEquals(r2, null)) return false;

                r1.Reduce();
                r2.Reduce();
                return (r1._numerator == r2._numerator && r1._denominator == r2._denominator);
            }

            public static bool operator ==(Rational r1, int n)
            {
                r1.Reduce();
                return (r1.IsInt && r1.Num == n);
            }

            public static bool operator !=(Rational r1, int n)
            {
                return !(r1 == n);
            }

            public static bool operator !=(Rational r1, Rational r2)
            {
                return !(r1 == r2);
            }

            public static bool operator <(Rational r1, Rational r2)
            {
                var cb = CommonBase(r1, r2);
                return cb.Item1 < cb.Item2;
            }

            public static bool operator <(Rational r1, int n)
            {
                return r1._numerator < r1._denominator * n;
            }

            public static bool operator >(Rational r1, int n)
            {
                return r1._numerator > r1._denominator * n;
            }

            public static bool operator <=(Rational r1, int n)
            {
                return r1._numerator <= r1._denominator * n;
            }

            public static bool operator >=(Rational r1, int n)
            {
                return r1._numerator >= r1._denominator * n;
            }

            public static bool operator <=(Rational r1, Rational r2)
            {
                var cb = CommonBase(r1, r2);
                return cb.Item1 <= cb.Item2;
            }

            public static bool operator >=(Rational r1, Rational r2)
            {
                return r2 <= r1;
            }

            public static bool operator >(Rational r1, Rational r2)
            {
                return r2 < r1;
            }

            public static explicit operator double(Rational r)
            {
                return (double)r._numerator / (double)r._denominator;
            }

            public static Rational operator -(Rational r)
            {
                return new Rational(-r._numerator, r._denominator);
            }

            public static Rational operator +(Rational r1, Rational r2)
            {
                var cb = CommonBase(r1, r2);
                return new Rational(cb.Item1 + cb.Item2, Lcm(r1._denominator, r2._denominator));
            }

            public static Rational operator -(Rational r1, Rational r2)
            {
                return r1 + -r2;
            }

            public static Rational operator *(Rational r1, Rational r2)
            {
                return new Rational(r1._numerator * r2._numerator, r1._denominator * r2._denominator);
            }

            public static Rational operator *(int n, Rational r2)
            {
                return new Rational(n * r2._numerator, r2._denominator);
            }

            public static Rational operator /(Rational r1, Rational r2)
            {
                if (r2._numerator == 0)
                {
                    throw new DivideByZeroException();
                }

                int num = r1._numerator * r2._denominator;
                int den = r1._denominator * r2._numerator;
                return new Rational(num, den);
            }

            public static Rational operator %(Rational r1, Rational r2)
            {
                if (r2._numerator == 0)
                {
                    throw new DivideByZeroException();
                }

                Rational res = r1 - new Rational((r1 / r2).Floor()) * r2;
                if(res < 0)
                {
                    res += r2;
                }

                return res;
            }

            public override string ToString()
            {
                return _denominator == 1 ? _numerator.ToString() : $"({_numerator}/{_denominator})";
            }
        }            
    }
}
